import React, { FC, useState } from 'react';
import { styles } from './MutlitSelectStyles';
import { Item, Label, NativeBase, Text, View, Icon } from 'native-base';
import { TouchableOpacity } from 'react-native';
import { SelectSearchBar } from './SelectSearchBar';
export type ItemProp = { label: string; value: string };
export type MultiSelectTagDropDownProps = {
  pickerList: ItemProp[];
  label?: string;
  labelProps?: NativeBase.Label;
  onChange: (val: string[]) => void;
  validationInfo?: string[];
};
export const MultiSelectDropDown: FC<MultiSelectTagDropDownProps> = (
  props: MultiSelectTagDropDownProps
) => {
  const { label, labelProps, pickerList, onChange, validationInfo } = props;
  const [showPickerList, setShowPickerList] = useState<boolean>(false);
  const [pickedList, setPickedList] = useState<ItemProp[]>([]);
  const removeItem = (val: ItemProp) => {
    const temp = pickedList.filter((item) => item.value !== val.value);
    setPickedList(temp);
    onChange(temp.map((item) => item.value));
  };
  const renderTags = () => {
    if (pickedList.length === 0) {
      return <Text style={{ marginTop: 10 }}>Click to select</Text>;
    }
    return pickedList.map((item, index) => {
      return (
        <View style={styles.tagContainer} key={index}>
          <Text style={{ marginRight: 5 }}>{item.label}</Text>
          <Icon name={'close'} onPress={() => removeItem(item)} />
        </View>
      );
    });
  };
  const onComplete = (val: ItemProp[]) => {
    setPickedList(val);
    onChange(val.map((item) => item.value));
  };
  return (
    <Item stackedLabel={label !== undefined} style={styles.itemStyle}>
      {label && (
        <Label
          {...labelProps}
          style={
            labelProps?.style
              ? { ...styles.textDefault, ...(labelProps.style as object) }
              : styles.textDefault
          }
        >
          {label}
          {'   '}
          {validationInfo && validationInfo?.length > 0 && (
            <Text style={{ color: '#f39c12', marginLeft: 5 }}>
              {validationInfo}
            </Text>
          )}
        </Label>
      )}
      <TouchableOpacity
        style={styles.default}
        onPress={() => setShowPickerList(!showPickerList)}
      >
        <View style={styles.multiSelect}>{renderTags()}</View>
      </TouchableOpacity>
      <SelectSearchBar
        onComplete={onComplete}
        data={pickerList}
        showModal={showPickerList}
        closeModal={() => setShowPickerList(false)}
        value={pickedList}
      />
    </Item>
  );
};
